  function Q = adapttrapez_simple(f,a,b,tol)

% function Q = adapttrapez_simple(f,a,b,tol)
%
% Zweck: approximiere das bestimmte Integral von f(x) von a bis b bis
%        auf die Toleranz tol mit adaptiver Trapez Quadratur
%
% Parameters: f   ... die zu integrierende Funktion 
%             a,b ... linke/rechte Integrations-Grenzen
%             tol ... Toleranz
%
% Returns: Q ... Integral Approximation
%
% Notes: Als Fehler-Schaetzer wird der in Bsp. (14) & (15) verwendet.
%        Programm-Schwaechen:
%
%          - Dieses Programm ist sehr ineffizient, da es die Funktion immer
%            von neuem auswerten muss.
%          - Die Rekursion wird nie gestoppt.
%

% Berechne Fehler-Schaetzer
  Q = 0.5*(b - a)*(f(a) + f(b));  % Trapezregel ueber ganzes Intervall [a,b]
  m = 0.5*(a + b);                % Intervall-Mitte
  Ql = 0.5*(m - a)*(f(a) + f(m)); % Trapezregel ueber linke  Intervall-Haelfte
  Qr = 0.5*(b - m)*(f(m) + f(b)); % Trapezregel ueber rechte Intervall-Haelfte
  E2 = abs(Q - (Ql + Qr))/3.;     % Fehler-Schaetzer

% Ueberpruefe ob Toleranz erreicht
  if ( E2 < tol ) % Toleranz erreicht?
    Q = Ql + Qr;
  else % Teile das Intervall weiter auf
    Ql = adapttrapez_simple(f,a,0.5*(a + b),0.5*tol);
    Qr = adapttrapez_simple(f,0.5*(a + b),b,0.5*tol);
    Q = Ql + Qr;
  end

